from django.db import models


# Create your models here.
# book：name、pub_date、readcount、commentcount、is_delete
# people：name、gender、description、book、is_delete
# 模型类对应的表的名字，默认是 book_bookinfo
class BookInfo(models.Model):
    name = models.CharField(max_length=20, verbose_name='书名')
    pub_date = models.DateField(null=False, verbose_name='发布日期')
    readcount = models.IntegerField(default=0, verbose_name='阅读总量')
    commentcount = models.IntegerField(default=0, verbose_name='评论总量')
    is_delete = models.BooleanField(default=False, verbose_name='逻辑删除')

    class Meta:
        db_table = 'bookinfo'

    def __str__(self):
        return self.name


class PeopleInfo(models.Model):
    GENDER_CHOICES = (
        (0, 'male'),
        (1, 'female'),
    )

    name = models.CharField(max_length=20, verbose_name='人名')
    gender = models.IntegerField(choices=GENDER_CHOICES, default=0, verbose_name='性别')
    description = models.CharField(max_length=1000, null=True, verbose_name='人物描述')
    book = models.ForeignKey(BookInfo, on_delete=models.CASCADE, verbose_name='书籍id')
    is_delete = models.BooleanField(default=False, verbose_name='逻辑删除')

    class Meta:
        db_table = 'peopleinfo'

    def __str__(self):
        return self.name
