import json

from django.http import HttpResponse, JsonResponse

# Create your views here.
from django.shortcuts import render
from django.views import View


def test(request):
    return HttpResponse("test")


def index(request, num2, num1):
    # GET QueryDict
    bookname = request.GET.getlist('bookname', '水浒传')
    pub_date = request.GET.get('pub_date')
    return HttpResponse('bookname:' + str(bookname) + ',pub_date:' + pub_date)


def post_form(request):
    """
    提取请求中的表单数据
    :param request:
    :return:
    """
    print(request.POST.get('name'))
    print(request.POST.getlist('name'))
    print(request.POST.get('readcount'))
    return HttpResponse('post_form')


def post_json(request):
    """
    提取请求中的json数据
    :param request:
    :return:
    """
    body = request.body
    body_dict = json.loads(body)
    print(body_dict['name'])
    print(body_dict['readcount'])
    print(body_dict['peoples'])
    print(request.META['CONTENT_TYPE'])
    print(request.META['HTTP_HOST'])
    return HttpResponse('post_json')


# HttpResponse
def create_response(request):
    # content 设置响应体，必须是字节码数据类型，或者str数据
    # content_type 设置响应体类型，MIME type 字符串
    # status 响应的状态码
    # reason 响应状态码的描述信息
    # charset 响应体的文本编码类型
    """
    {
        "name": "天龙八部",
        "readcount": 20000,
        "peoples": ["乔峰", "虚竹", "段誉"]
    }
    """
    # python 字典构建json字符串
    # json dumps
    #      loads
    book = {
        'name': '天龙八部',
        'readcount': 20000,
        'peoples': ['乔峰', '虚竹', '段誉']
    }
    print(book)
    book_json = json.dumps(book)
    print(book_json)
    return HttpResponse(content=book_json, content_type='application/json', status='200')


# HttpResponse
def create_response(request):
    # content 响应体数据，必须是字节码类型的数据
    # content_type 表示响应体的数据类型，MIME application/json
    # status 响应状态行 响应码
    """
    {
    "name": "天龙八部",
    "readcount": 20000,
    "peoples": ["乔峰", "虚竹", "段誉"]
    }
    """
    # json
    # dumps 字典转 json 字符串
    # loads json 转换为字典
    book = {
        'name': '天龙八部',
        'readcount': 20000,
        'peoples': ["乔峰", "虚竹", "段誉"]
    }
    print(book)
    book_json = json.dumps(book)
    print(book_json)
    return HttpResponse(content=book_json, content_type='application/json', status='200')


# JsonResponse
def create_jsonresponse(request):
    book = {
        'name': '天龙八部',
        'readcount': 20000,
        'peoples': ["乔峰", "虚竹", "段誉"]
    }
    return JsonResponse(book)


def set_cookie(request):
    # 浏览器第一次请求某个服务器的时候，是不带 Cookie 信息的
    # 服务器收到http请求后，会先检查http请求的 cookies 请求头，获取 cookie 信息
    # 如果没有想要的 cookie 信息，服务器会生成一个 key-value 数据，名称和值都由服务器端自己定义，通过 http 响应的 set-cookie 响应头返回给浏览器
    # 浏览器将响应中的 set-cookie 响应头里面的 key-value 提取出来，在本地保存起来，比如保存到某个目录下的文件中或者 sqlite 数据库中
    # 浏览器下次请求同一个网站时就自动在 http 请求头中带上 key-value 键值对，放在 cookies 请求头里面
    # request.COOKIES 可以从 cookies 属性里面获取 cookies 请求头，cookies 是一个字典类型数据
    # response.set_cookie(key, value, max_age) 可以给响应设置 Set-Cookie 响应头，把 cookie 数据返回给浏览器
    # key cookie 的键，字符串
    # value cookie 的值，字符串
    # max_age 表示 cookie 的保存时间，以秒为单位，默认值表示 cookie 值的保存时间为会话关闭时自动删掉
    response = HttpResponse('set cookie')

    if 'user_id' in request.COOKIES.keys():
        user_id = request.COOKIES.get('user_id')
        print(user_id)
        response.delete_cookie('user_id')
    else:
        key = 'user_id'
        value = '000001111'
        response.set_cookie(key, value, max_age=3600)

    return response


def set_session(request):
    # 浏览器第一次访问服务器的时候，cookie 里面没有 session 相关信息，如果是用户登录，请求会携带用户名和密码的信息
    # 当我们的服务器收到这个请求后，处理请求，返回 http 响应，并且会在响应中添加 set-cookie 响应头，里面返回 session_id 和 session_key 这个键值对
    #   1. session 中间件先从 cookie 里面获取 session_id 这个cookie 的值，这个值就是 session_key，如果获取不到 session_key 就
    #   随机生成一个 32 位的由小写字母和数字组成的字符串作为 session_key
    #   2. 视图会进行用户名和密码验证，验证没有问题，一般会把 user_id 从用户表里面取出来，保存到 session 里面，以 'user_id' 为
    #   key，数据库中查询到的 user_id 值为 value，存储在 session 里面
    #   3. 视图返回 response 后，session 中间件还会在 response 上设置一个 session_id 这个 cookie 值，这个 cookie 值的 key 是
    #   ‘session_id’，value 是第1步产生的 session_key
    #   4. session 中间件把 session 这个字典数据保存在数据库中，session_key 是主键的值，session 字典转换为字符串后保存为 data 的值
    # 在浏览器收到响应数据后，会从 cookie 里面获取到 session_id 这个 cookie 的 key-value，并且保存起来
    # 浏览器第二次访问服务器的时候，cookie 里面就自动带上 session_id 这个 cookie 的 key-value
    # 服务器第二次收到请求后，就可以从 cookie 里面获取到 session_id 这个 key-value，也可以得到前面的 session_key，然后从数据库中加载查询 session 的数据，并且转换为字典
    username = request.GET.get('username')
    password = request.GET.get('password')
    # 验证用户名和密码

    # 设置 session
    request.session['user_id'] = 123456789

    return HttpResponse('set session')


def get_session(request):
    user_id = request.session.get('user_id')
    print(user_id)
    return HttpResponse('get session')


def register(request):
    if request.method == "GET":
        return render(request, 'register.html')
    elif request.method == "POST":
        # 处理注册请求逻辑

        return HttpResponse('POST')
    else:
        pass

    return HttpResponse('regiseter')


class RegisterView(View):
    def get(self, request):
        return render(request, 'register.html')

    def post(self, request):
        # 处理用户注册逻辑
        return HttpResponse('post')


def test_middleware(request):
    print('视图函数处理 request')
    return HttpResponse('middleware')
